Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5856)

Unified Diff: chrome/test/data/push_messaging/push_test.js

Issue 2469293002: Handle push resubscribes with no sender info (avoids DCHECK) (Closed)
Patch Set: rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/push_messaging/push_test.js
diff --git a/chrome/test/data/push_messaging/push_test.js b/chrome/test/data/push_messaging/push_test.js
index 180f1a622860570361433804d1dc4c6b9e53575f..c4d168a608340b5c1d4a70c749e416f5e705e48d 100644
--- a/chrome/test/data/push_messaging/push_test.js
+++ b/chrome/test/data/push_messaging/push_test.js
@@ -119,6 +119,18 @@ function documentSubscribePush() {
}).catch(sendErrorToTest);
}
+function documentSubscribePushWithNumericKey() {
+ navigator.serviceWorker.ready.then(function(swRegistration) {
+ return swRegistration.pushManager.subscribe({
+ userVisibleOnly: true,
+ applicationServerKey: new TextEncoder().encode('1234567890')
+ })
+ .then(function(subscription) {
+ sendResultToTest(subscription.endpoint);
+ });
+ }).catch(sendErrorToTest);
+}
+
function workerSubscribePush() {
// Send the message to the worker for it to subscribe
navigator.serviceWorker.controller.postMessage({command: 'workerSubscribe'});
@@ -126,7 +138,8 @@ function workerSubscribePush() {
function workerSubscribePushNoKey() {
// The worker will try to subscribe without providing a key. This should
// succeed if the worker was previously subscribed and fail otherwise.
navigator.serviceWorker.controller.postMessage(
{command: 'workerSubscribeNoKey'});
}
@@ -126,7 +138,8 @@ function workerSubscribePush() {
function workerSubscribePushNoKey() {
// The worker will try to subscribe without providing a key. This should
- // succeed if the worker was previously subscribed and fail otherwise.
+ // succeed if the worker was previously subscribed with a numeric key
+ // and fail otherwise.
navigator.serviceWorker.controller.postMessage(
{command: 'workerSubscribeNoKey'});

Powered by Google App Engine
This is Rietveld 408576698